@@ -593,7 +593,7 @@ class DataTransform(forms.ModelForm):
             queryset=self.instance.datatransformerconstants_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'id': str(uuid.uuid4())}]
 
         )
 
@@ -602,7 +602,7 @@ class DataTransform(forms.ModelForm):
             queryset=self.instance.hardwaredatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'id': str(uuid.uuid4())}]
 
         )
 
@@ -611,7 +611,7 @@ class DataTransform(forms.ModelForm):
             queryset=self.instance.hardwarestatsdatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'id': str(uuid.uuid4())}]
 
         )
 
@@ -735,7 +735,7 @@ class DataTransformRoot(forms.ModelForm):
             queryset=self.instance.datatransformerconstants_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'id': str(uuid.uuid4())}]
 
         )
 
@@ -744,7 +744,7 @@ class DataTransformRoot(forms.ModelForm):
             queryset=self.instance.hardwaredatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'id': str(uuid.uuid4())}]
 
         )
 
@@ -753,7 +753,7 @@ class DataTransformRoot(forms.ModelForm):
             queryset=self.instance.hardwarestatsdatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'id': str(uuid.uuid4())}]
 
         )
 
