@@ -442,7 +442,8 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         data_transformer_family = data_transformer_root.get_family()
         children_dict = defaultdict(list)
         for descendant in data_transformer_family:
-            children_dict[descendant.get_parent().pk].append(descendant)
+            for child in descendant.get_children():
+                children_dict[descendant.pk].append(child)
 
         context = {}
         context['children'] = children_dict
